@@ -6,16 +6,24 @@ use 5.010;
 
 use parent 'Class::Accessor';
 
-our $VERSION = '2.02';
+our $VERSION = '3.00';
 
 Travel::Status::DE::EFA::Stop->mk_ro_accessors(
-	qw(arr dep name name_suf platform));
+	qw(sched_arr rt_arr arr
+	  sched_dep rt_dep dep
+	  occupancy
+	  place name full_name id latlon
+	  platform niveau)
+);
 
 sub new {
 	my ( $obj, %conf ) = @_;
 
 	my $ref = \%conf;
 
+	$ref->{arr} //= $ref->{rt_arr} // $ref->{sched_arr};
+	$ref->{dep} //= $ref->{rt_dep} // $ref->{sched_dep};
+
 	return bless( $ref, $obj );
 }
 
@@ -47,7 +55,7 @@ in a Travel::Status::DE::EFA::Result's route
 
 =head1 VERSION
 
-version 2.02
+version 3.00
 
 =head1 DESCRIPTION
 
@@ -71,12 +79,20 @@ first scheduled stop.
 DateTime(3pm) object holding departure date and time. undef if this is the
 final scheduled stop.
 
-=item $stop->name
+=item $stop->id
+
+Stop ID.
+
+=item $stop->place
+
+City name, for instance "Essen".
+
+=item $stop->full_name
 
 stop name with city prefix ("I<City> I<Stop>", for instance
 "Essen RE<uuml>ttenscheider Stern").
 
-=item $stop->name_suf
+=item $stop->name
 
 stop name without city prefix, for instance "RE<uuml>ttenscheider Stern".
 
